@@ -409,6 +409,21 @@ public:
   bool isTransform() const Q_DECL_OVERRIDE;
 };
 
+class GoldenPointOfTwoPointsConstructor
+  : public StandardConstructorBase
+{
+  ArgsParser mparser;
+public:
+  GoldenPointOfTwoPointsConstructor();
+  ~GoldenPointOfTwoPointsConstructor();
+  void drawprelim( const ObjectDrawer& drawer, KigPainter& p, const std::vector<ObjectCalcer*>& parents,
+                   const KigDocument& ) const Q_DECL_OVERRIDE;
+  std::vector<ObjectHolder*> build( const std::vector<ObjectCalcer*>& os, KigDocument& d,
+                 KigWidget& w ) const Q_DECL_OVERRIDE;
+  void plug( KigPart* doc, KigGUIAction* kact ) Q_DECL_OVERRIDE;
+  bool isTransform() const Q_DECL_OVERRIDE;
+};
+
 class TestConstructor
   : public StandardConstructorBase
 {
