@@ -20,8 +20,8 @@
 
 #include "macro.h"
 
-#include <qlabel.h>
-#include <qlayout.h>
+#include <QLabel>
+#include <QLayout>
 
 #include <QDebug>
 #include <QDialog>
