@@ -35,10 +35,10 @@ class ScriptActionsProvider
 {
   int mns;
 public:
-  void fillUpMenu( NormalModePopupObjects& popup, int menu, int& nextfree );
+  void fillUpMenu( NormalModePopupObjects& popup, int menu, int& nextfree ) override;
   bool executeAction( int menu, int& id, const std::vector<ObjectHolder*>& os,
                       NormalModePopupObjects& popup,
-                      KigPart& doc, KigWidget& w, NormalMode& m );
+                      KigPart& doc, KigWidget& w, NormalMode& m ) override;
 };
 
 #endif
