@@ -358,7 +358,7 @@ TypesDialog::TypesDialog( QWidget* parent, KigPart& part )
 
   mtypeswidget = new Ui_TypesWidget();
   mtypeswidget->setupUi( mainWidget );
-  mainWidget->layout()->setMargin( 0 );
+  mainWidget->layout()->setContentsMargins( 0, 0, 0, 0 );
 
   // model creation and usage
   mmodel = new TypesModel( mtypeswidget->typeList );
@@ -562,7 +562,7 @@ void TypesDialog::slotCancel()
 QModelIndexList TypesDialog::selectedRows() const
 {
   QModelIndexList indexes = mtypeswidget->typeList->selectionModel()->selectedRows();
-  qSort( indexes );
+  std::sort( indexes.begin(), indexes.end() );
   return indexes;
 }
 
