@@ -48,30 +48,30 @@ public:
             double angle_in_radials, bool markRightAngle );
   ~AngleImp();
 
-  ObjectImp* transform( const Transformation& ) const;
+  ObjectImp* transform( const Transformation& ) const Q_DECL_OVERRIDE;
 
-  void draw( KigPainter& p ) const;
-  bool contains( const Coordinate& p, int width, const KigWidget& ) const;
-  bool inRect( const Rect& r, int width, const KigWidget& ) const;
-  Rect surroundingRect() const;
+  void draw( KigPainter& p ) const Q_DECL_OVERRIDE;
+  bool contains( const Coordinate& p, int width, const KigWidget& ) const Q_DECL_OVERRIDE;
+  bool inRect( const Rect& r, int width, const KigWidget& ) const Q_DECL_OVERRIDE;
+  Rect surroundingRect() const Q_DECL_OVERRIDE;
 
-  Coordinate attachPoint() const;
-  int numberOfProperties() const;
-  const QByteArrayList properties() const;
-  const QByteArrayList propertiesInternalNames() const;
-  ObjectImp* property( int which, const KigDocument& w ) const;
-  const char* iconForProperty( int which ) const;
-  const ObjectImpType* impRequirementForProperty( int which ) const;
-  bool isPropertyDefinedOnOrThroughThisImp( int which ) const;
+  Coordinate attachPoint() const Q_DECL_OVERRIDE;
+  int numberOfProperties() const Q_DECL_OVERRIDE;
+  const QByteArrayList properties() const Q_DECL_OVERRIDE;
+  const QByteArrayList propertiesInternalNames() const Q_DECL_OVERRIDE;
+  ObjectImp* property( int which, const KigDocument& w ) const Q_DECL_OVERRIDE;
+  const char* iconForProperty( int which ) const Q_DECL_OVERRIDE;
+  const ObjectImpType* impRequirementForProperty( int which ) const Q_DECL_OVERRIDE;
+  bool isPropertyDefinedOnOrThroughThisImp( int which ) const Q_DECL_OVERRIDE;
 
-  ObjectImp* copy() const;
+  ObjectImp* copy() const Q_DECL_OVERRIDE;
 
   /**
    * Return the size in radians of this angle.
    */
   double size() const;
-  const ObjectImpType* type() const;
-  void visit( ObjectImpVisitor* vtor ) const;
+  const ObjectImpType* type() const Q_DECL_OVERRIDE;
+  void visit( ObjectImpVisitor* vtor ) const Q_DECL_OVERRIDE;
 
   /**
    * Return the center of this angle.
@@ -90,7 +90,7 @@ public:
 
   void setMarkRightAngle( bool markRightAngle ) { mmarkRightAngle = markRightAngle; }
 
-  bool equals( const ObjectImp& rhs ) const;
+  bool equals( const ObjectImp& rhs ) const Q_DECL_OVERRIDE;
 };
 
 /**
@@ -113,25 +113,25 @@ public:
   VectorImp( const Coordinate& a, const Coordinate& b );
   ~VectorImp();
 
-  ObjectImp* transform( const Transformation& ) const;
+  ObjectImp* transform( const Transformation& ) const Q_DECL_OVERRIDE;
 
-  const Coordinate getPoint( double param, const KigDocument& ) const;
-  double getParam( const Coordinate&, const KigDocument& ) const;
+  const Coordinate getPoint( double param, const KigDocument& ) const Q_DECL_OVERRIDE;
+  double getParam( const Coordinate&, const KigDocument& ) const Q_DECL_OVERRIDE;
 
-  void draw( KigPainter& p ) const;
-  bool contains( const Coordinate& p, int width, const KigWidget& ) const;
-  bool inRect( const Rect& r, int width, const KigWidget& ) const;
-  Rect surroundingRect() const;
+  void draw( KigPainter& p ) const Q_DECL_OVERRIDE;
+  bool contains( const Coordinate& p, int width, const KigWidget& ) const Q_DECL_OVERRIDE;
+  bool inRect( const Rect& r, int width, const KigWidget& ) const Q_DECL_OVERRIDE;
+  Rect surroundingRect() const Q_DECL_OVERRIDE;
 
-  int numberOfProperties() const;
-  const QByteArrayList properties() const;
-  const QByteArrayList propertiesInternalNames() const;
-  ObjectImp* property( int which, const KigDocument& w ) const;
-  const char* iconForProperty( int which ) const;
-  const ObjectImpType* impRequirementForProperty( int which ) const;
-  bool isPropertyDefinedOnOrThroughThisImp( int which ) const;
+  int numberOfProperties() const Q_DECL_OVERRIDE;
+  const QByteArrayList properties() const Q_DECL_OVERRIDE;
+  const QByteArrayList propertiesInternalNames() const Q_DECL_OVERRIDE;
+  ObjectImp* property( int which, const KigDocument& w ) const Q_DECL_OVERRIDE;
+  const char* iconForProperty( int which ) const Q_DECL_OVERRIDE;
+  const ObjectImpType* impRequirementForProperty( int which ) const Q_DECL_OVERRIDE;
+  bool isPropertyDefinedOnOrThroughThisImp( int which ) const Q_DECL_OVERRIDE;
 
-  VectorImp* copy() const;
+  VectorImp* copy() const Q_DECL_OVERRIDE;
 
   /**
    * Return the direction of this vector.
@@ -154,12 +154,12 @@ public:
    */
   LineData data() const;
 
-  const ObjectImpType* type() const;
-  void visit( ObjectImpVisitor* vtor ) const;
+  const ObjectImpType* type() const Q_DECL_OVERRIDE;
+  void visit( ObjectImpVisitor* vtor ) const Q_DECL_OVERRIDE;
 
-  bool equals( const ObjectImp& rhs ) const;
+  bool equals( const ObjectImp& rhs ) const Q_DECL_OVERRIDE;
 
-  bool containsPoint( const Coordinate& p, const KigDocument& doc ) const;
+  bool containsPoint( const Coordinate& p, const KigDocument& doc ) const Q_DECL_OVERRIDE;
   bool internalContainsPoint( const Coordinate& p, double threshold ) const;
 };
 
@@ -187,29 +187,29 @@ public:
   ArcImp( const Coordinate& center, const double radius,
           const double startangle, const double angle );
   ~ArcImp();
-  ArcImp* copy() const;
+  ArcImp* copy() const Q_DECL_OVERRIDE;
 
-  ObjectImp* transform( const Transformation& t ) const;
+  ObjectImp* transform( const Transformation& t ) const Q_DECL_OVERRIDE;
 
-  void draw( KigPainter& p ) const;
-  bool contains( const Coordinate& p, int width, const KigWidget& w ) const;
-  bool inRect( const Rect& r, int width, const KigWidget& si ) const;
-  Rect surroundingRect() const;
+  void draw( KigPainter& p ) const Q_DECL_OVERRIDE;
+  bool contains( const Coordinate& p, int width, const KigWidget& w ) const Q_DECL_OVERRIDE;
+  bool inRect( const Rect& r, int width, const KigWidget& si ) const Q_DECL_OVERRIDE;
+  Rect surroundingRect() const Q_DECL_OVERRIDE;
   bool valid() const;
 
-  int numberOfProperties() const;
-  const QByteArrayList properties() const;
-  const QByteArrayList propertiesInternalNames() const;
-  ObjectImp* property( int which, const KigDocument& d ) const;
-  const char* iconForProperty( int which ) const;
-  const ObjectImpType* impRequirementForProperty( int which ) const;
-  bool isPropertyDefinedOnOrThroughThisImp( int which ) const;
+  int numberOfProperties() const Q_DECL_OVERRIDE;
+  const QByteArrayList properties() const Q_DECL_OVERRIDE;
+  const QByteArrayList propertiesInternalNames() const Q_DECL_OVERRIDE;
+  ObjectImp* property( int which, const KigDocument& d ) const Q_DECL_OVERRIDE;
+  const char* iconForProperty( int which ) const Q_DECL_OVERRIDE;
+  const ObjectImpType* impRequirementForProperty( int which ) const Q_DECL_OVERRIDE;
+  bool isPropertyDefinedOnOrThroughThisImp( int which ) const Q_DECL_OVERRIDE;
 
-  const ObjectImpType* type() const;
-  void visit( ObjectImpVisitor* vtor ) const;
+  const ObjectImpType* type() const Q_DECL_OVERRIDE;
+  void visit( ObjectImpVisitor* vtor ) const Q_DECL_OVERRIDE;
 
-  double getParam( const Coordinate& c, const KigDocument& d ) const;
-  const Coordinate getPoint( double p, const KigDocument& d ) const;
+  double getParam( const Coordinate& c, const KigDocument& d ) const Q_DECL_OVERRIDE;
+  const Coordinate getPoint( double p, const KigDocument& d ) const Q_DECL_OVERRIDE;
 
   /**
    * Return the center of this arc.
@@ -244,9 +244,9 @@ public:
    */
   double sectorSurface() const;
 
-  bool equals( const ObjectImp& rhs ) const;
+  bool equals( const ObjectImp& rhs ) const Q_DECL_OVERRIDE;
 
-  bool containsPoint( const Coordinate& p, const KigDocument& doc ) const;
+  bool containsPoint( const Coordinate& p, const KigDocument& doc ) const Q_DECL_OVERRIDE;
   bool internalContainsPoint( const Coordinate& p, double threshold ) const;
 };
 
